C2paViewerThemeData class

Theme data for C2PA manifest viewer widgets.

Provides colors, text styles, and other visual properties that can be customized by wrapping your widget tree with C2paViewerTheme.

Constructors

C2paViewerThemeData({Color validColor = const Color(0xFF1B8D3E), Color invalidColor = const Color(0xFFD93025), Color unrecognizedColor = const Color(0xFFE8710A), Color noCredentialColor = const Color(0xFF9E9E9E), Color surfaceColor = const Color(0xFFFFFFFF), Color surfaceVariantColor = const Color(0xFFF5F5F5), Color borderColor = const Color(0xFFE0E0E0), Color textPrimaryColor = const Color(0xFF1A1A1A), Color textSecondaryColor = const Color(0xFF6B6B6B), Color iconColor = const Color(0xFF6B6B6B), Color selectedNodeBorderColor = const Color(0xFF1A73E8), Color pathNodeBorderColor = const Color(0xFF5F6368), Color defaultNodeBorderColor = const Color(0xFFDADCE0), Color edgeColor = const Color(0xFFDADCE0), TextStyle titleLargeStyle = const TextStyle(fontSize: 18, fontWeight: FontWeight.w600, height: 1.3), TextStyle titleMediumStyle = const TextStyle(fontSize: 15, fontWeight: FontWeight.w600, height: 1.3), TextStyle titleSmallStyle = const TextStyle(fontSize: 13, fontWeight: FontWeight.w600, height: 1.3), TextStyle bodyStyle = const TextStyle(fontSize: 14, fontWeight: FontWeight.w400, height: 1.5), TextStyle bodySmallStyle = const TextStyle(fontSize: 12, fontWeight: FontWeight.w400, height: 1.4), TextStyle labelStyle = const TextStyle(fontSize: 11, fontWeight: FontWeight.w500, letterSpacing: 0.5, height: 1.3), double sidebarWidth = 360, double thumbnailSize = 280, double nodeWidth = 200, double nodeHeight = 100, double nodeSpacingX = 60, double nodeSpacingY = 80, BorderRadius cardRadius = const BorderRadius.all(Radius.circular(12)), BorderRadius sectionRadius = const BorderRadius.all(Radius.circular(8))})
const
C2paViewerThemeData.dark()
factory

Properties

bodySmallStyle TextStyle
final
bodyStyle TextStyle
final
borderColor Color
final
cardRadius BorderRadius
final
defaultNodeBorderColor Color
final
edgeColor Color
final
hashCode int
The hash code for this object.
no setterinherited
iconColor Color
final
invalidColor Color
final
labelStyle TextStyle
final
noCredentialColor Color
final
nodeHeight double
final
nodeSpacingX double
final
nodeSpacingY double
final
nodeWidth double
final
pathNodeBorderColor Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sectionRadius BorderRadius
final
selectedNodeBorderColor Color
final
sidebarWidth double
final
surfaceColor Color
final
surfaceVariantColor Color
final
textPrimaryColor Color
final
textSecondaryColor Color
final
thumbnailSize double
final
titleLargeStyle TextStyle
final
titleMediumStyle TextStyle
final
titleSmallStyle TextStyle
final
unrecognizedColor Color
final
validColor Color
final

Methods

colorForStatus(ValidationStatus status) Color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

defaults → const C2paViewerThemeData