CustomField class

A generic key-value field for non-standard C2PA data.

Custom fields can originate from vendor-specific assertions, non-standard action parameters, or extra fields within known assertions.

Constructors

CustomField({required String key, required dynamic value, required String source, String? parentLabel})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isList bool
no setter
isMap bool
no setter
isSimple bool
no setter
key String
final
parentLabel String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toFlatEntries({String prefix = ''}) List<MapEntry<String, String>>
Flatten a nested Map/List into displayable key-value pairs.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited