ThumbnailData class

Thumbnail data from a C2PA manifest.

Constructors

ThumbnailData({required String format, String? identifier, Uint8List? data})
const
ThumbnailData.fromJson(Map<String, dynamic> json)
factory

Properties

data Uint8List?
final
format String
final
hashCode int
The hash code for this object.
no setterinherited
identifier String?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited