ActionDisplayInfo class

Display info for a single action in the process section.

Annotations

Constructors

ActionDisplayInfo({required String actionType, required String label, DateTime? when, String? softwareAgent, bool isAiGenerated = false, List<CustomField> customParams = const []})
const

Properties

actionType String
final
customParams List<CustomField>
final
hashCode int
The hash code for this object.
no setterinherited
isAiGenerated bool
final
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
softwareAgent String?
final
when DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

humanLabel(String actionType) String