ExifDisplayData class

Display-ready EXIF / camera capture data.

Annotations

Constructors

ExifDisplayData({String? creator, String? copyright, DateTime? captureDate, String? cameraMake, String? cameraModel, String? lensMake, String? lensModel, String? exposureTime, String? fNumber, String? focalLength, String? iso, int? width, int? height, double? latitude, double? longitude})
const

Properties

cameraLabel String?
no setter
cameraMake String?
final
cameraModel String?
final
captureDate DateTime?
final
final
creator String?
final
dimensionsLabel String?
no setter
exposureTime String?
final
fNumber String?
final
focalLength String?
final
hashCode int
The hash code for this object.
no setterinherited
hasLocation bool
no setter
height int?
final
iso String?
final
latitude double?
final
lensLabel String?
no setter
lensMake String?
final
lensModel String?
final
longitude double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited