ProvenanceNode class

A node in the provenance DAG.

Each node represents an asset (the main asset or one of its ingredients) and its credential status. Nodes appear exactly once in the graph even when multiple parents reference the same manifest as an ingredient.

Annotations

Constructors

ProvenanceNode({required String id, ManifestSummary summary = const ManifestSummary(), DateTime? signedDate, ManifestViewData? manifestViewData})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
final
issuer String?
no setter
manifestViewData ManifestViewData?
The full manifest view data for this node, used when the user selects this node to show its details in the sidebar.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signedDate DateTime?
final
summary ManifestSummary
final
thumbnail ImageProvider<Object>?
no setter
title String?
no setter
validationResult ValidationResult
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited