manifestViewData property

ManifestViewData? manifestViewData
final

The full manifest view data for this node, used when the user selects this node to show its details in the sidebar.

Implementation

final ManifestViewData? manifestViewData;