ValidationResult class

Annotations

Constructors

ValidationResult({required ValidationStatus status, String? message})
const
ValidationResult.invalid([String? message])
const
ValidationResult.noCredential()
const
ValidationResult.unrecognized([String? message])
const
ValidationResult.untrusted()
The credential is structurally valid but the signing certificate is not in any trusted certificate list.
const
ValidationResult.valid()
const

Properties

hasCredential bool
no setter
hashCode int
The hash code for this object.
no setterinherited
isInvalid bool
no setter
isUnrecognized bool
no setter
isUntrusted bool
no setter
isValid bool
no setter
message String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ValidationStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited