ClaimGeneratorDisplayInfo class
Display info for the claim generator (app/device).
- Annotations
Constructors
-
ClaimGeneratorDisplayInfo({required String name, String? version, ImageProvider<
Object> ? icon}) -
const
Properties
- displayLabel → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
icon
→ ImageProvider<
Object> ? -
final
- name → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited