GenerativeInfo class
AI generation information.
- Annotations
Constructors
-
GenerativeInfo({required GenerativeType type, List<
String> softwareAgents = const []}) -
const
Properties
- description → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
softwareAgents
→ List<
String> -
final
- type → GenerativeType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited