ManifestViewData class
Display-ready data for the manifest detail panel.
- Annotations
Constructors
-
ManifestViewData({String? title, ImageProvider<
Object> ? thumbnail, ValidationResult validationResult = const ValidationResult.noCredential(), String? issuer, DateTime? signedDate, GenerativeInfo? generativeInfo, ClaimGeneratorDisplayInfo? claimGenerator, List<ActionDisplayInfo> actions = const [], List<IngredientDisplayInfo> ingredients = const [], List<String> aiToolsUsed = const [], ExifDisplayData? exifData, String? producer, List<SocialAccountDisplayInfo> socialAccounts = const [], bool doNotTrain = false, String? website, List<CustomField> customFields = const [], List<CustomField> exifCustomFields = const [], List<CustomField> creativeWorkCustomFields = const [], Map<String, dynamic> ? rawJson}) -
const
Properties
-
actions
→ List<
ActionDisplayInfo> -
final
-
aiToolsUsed
→ List<
String> -
final
- claimGenerator → ClaimGeneratorDisplayInfo?
-
final
-
creativeWorkCustomFields
→ List<
CustomField> -
final
-
customFields
→ List<
CustomField> -
final
- doNotTrain → bool
-
final
-
exifCustomFields
→ List<
CustomField> -
final
- exifData → ExifDisplayData?
-
final
- generativeInfo → GenerativeInfo?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ingredients
→ List<
IngredientDisplayInfo> -
final
- issuer → String?
-
final
- producer → String?
-
final
-
rawJson
→ Map<
String, dynamic> ? -
The raw JSON map for this manifest. Used for the "copy JSON" feature.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signedDate → DateTime?
-
final
-
final
-
thumbnail
→ ImageProvider<
Object> ? -
final
- title → String?
-
final
- validationResult → ValidationResult
-
final
- website → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited