ProvenanceGraph class
A directed acyclic graph of ProvenanceNodes.
Unlike a tree, a node may have multiple parents (when the same manifest is an ingredient of more than one parent). Each node appears exactly once in nodes; relationships are expressed through edges.
- Annotations
Constructors
-
ProvenanceGraph({required String rootId, required Map<
String, ProvenanceNode> nodes, required List<ProvenanceEdge> edges}) -
const
Properties
-
edges
→ List<
ProvenanceEdge> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
nodes
→ Map<
String, ProvenanceNode> -
final
- rootId → String
-
final
- rootNode → ProvenanceNode?
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
childIdsOf(
String parentId) → List< String> - All child IDs for a given parent.
-
findNode(
String id) → ProvenanceNode? -
hasChildren(
String nodeId) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parentIdsOf(
String childId) → List< String> - All parent IDs for a given child.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited