manifestViewData property
The full manifest view data for this node, used when the user selects this node to show its details in the sidebar.
Implementation
final ManifestViewData? manifestViewData;
The full manifest view data for this node, used when the user selects this node to show its details in the sidebar.
final ManifestViewData? manifestViewData;